/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 protected:
   void closeEvent(QCloseEvent *event) override;

 private:
   void loadSettings();
   void saveSettings();

   QLineEdit *m_text;
};

MainWindow::MainWindow()
{
   setMinimumSize(500, 225);

   QLabel *label = new QLabel("Text stored in Settings:");

   m_text = new QLineEdit();

   QPushButton *pb_load = new QPushButton();
   pb_load->setText("Load Settings");

   QPushButton *pb_save = new QPushButton();
   pb_save->setText("Save Settings");

   QPushButton *pb_close = new QPushButton();
   pb_close->setText("Close");

   QHBoxLayout *layout_1 = new QHBoxLayout();
   layout_1->addWidget(label);
   layout_1->addWidget(m_text);

   QHBoxLayout *layout_2 = new QHBoxLayout();
   layout_2->addStretch();
   layout_2->addWidget(pb_load);
   layout_2->addSpacing(10);
   layout_2->addWidget(pb_save);
   layout_2->addSpacing(10);
   layout_2->addWidget(pb_close);
   layout_2->addStretch();

   QVBoxLayout *layout_main = new QVBoxLayout(this);
   layout_main->setContentsMargins(30, 50, 30, 15);

   layout_main->addLayout(layout_1);
   layout_main->addStretch();
   layout_main->addLayout(layout_2);

   connect(pb_load,  &QPushButton::clicked, this, &MainWindow::loadSettings);
   connect(pb_save,  &QPushButton::clicked, this, &MainWindow::saveSettings);
   connect(pb_close, &QPushButton::clicked, this, &QWidget::close);

   loadSettings();
}

void MainWindow::loadSettings()
{
   QSettings settings("CopperSpice Journal","Example 20");

   QRect appRect = settings.value("position").toRect();

   if (appRect.isValid()) {
      setGeometry(appRect);
   }

   m_text->setText(settings.value("initialText").toString());
}

void MainWindow::saveSettings()
{
   QSettings settings("CopperSpice Journal","Example 20");

   settings.setValue("position",    this->geometry());
   settings.setValue("initialText", m_text->text());
}

void MainWindow::closeEvent(QCloseEvent *event)
{
   saveSettings();
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}
